Index: content/child/browser_font_resource_trusted.h |
diff --git a/content/child/browser_font_resource_trusted.h b/content/child/browser_font_resource_trusted.h |
index 2e399badca7964832db8c9ff7f8b879a3363d91f..aef873d80e538b14538cf1aaa1904751d4fe955b 100644 |
--- a/content/child/browser_font_resource_trusted.h |
+++ b/content/child/browser_font_resource_trusted.h |
@@ -9,6 +9,7 @@ |
#include <string> |
#include "base/macros.h" |
+#include "cc/paint/paint_canvas.h" |
#include "ppapi/c/pp_bool.h" |
#include "ppapi/c/pp_instance.h" |
#include "ppapi/c/pp_resource.h" |
@@ -17,8 +18,6 @@ |
#include "ppapi/shared_impl/ppapi_preferences.h" |
#include "ppapi/thunk/ppb_browser_font_trusted_api.h" |
-class SkCanvas; |
- |
namespace blink { |
class WebFont; |
} |
@@ -60,8 +59,8 @@ class BrowserFontResource_Trusted |
private: |
~BrowserFontResource_Trusted() override; |
- // Internal version of DrawTextAt that takes a mapped PlatformCanvas. |
- void DrawTextToCanvas(SkCanvas* destination, |
+ // Internal version of DrawTextAt that takes a mapped PaintCanvas. |
+ void DrawTextToCanvas(cc::PaintCanvas* destination, |
const PP_BrowserFont_Trusted_TextRun& text, |
const PP_Point* position, |
uint32_t color, |